<?php
    /**
     * Stats block template
     *
     * @param   array $block The block settings and attributes.
     * @param   string $content The block inner HTML (empty).
     * @param   bool $is_preview True during AJAX preview.
     * @param   (int|string) $post_id The post ID this block is saved to.
     *
     */

    // Create id attribute allowing for custom "anchor" value.
    $id = 'stats-' . $block['id'];
    if( !empty($block['anchor']) ) {
        $id = $block['anchor'];
    }

    // Create class attribute allowing for custom "className" and "align" values.
    $className = 'content-stats mb-1';
    if( !empty($block['className']) ) {
        $className .= ' ' . $block['className'];
    }
    ?>
<div class="<?php echo esc_attr($className); ?>" id="<?php echo esc_attr($id); ?>" data-scroll="data-scroll" data-scroll-speed="-.75">
  <div class="row position-relative zi-1 py-3 py-lg-4 text-center justify-content-md-center justify-content-lg-start">
    <?php
    
    $stat_values = get_field('stats');
    if( !empty($stat_values) ) {
        for ($i = 0; $i < count($stat_values); $i++) {
            $prefix     = get_field('stats_' . $i . '_prefix');
            $suffix     = get_field('stats_' . $i . '_suffix');
            $value      = get_field('stats_' . $i . '_value');
            $descr      = get_field('stats_' . $i . '_description');
            $anim       = get_field('stats_' . $i . '_animated');
            $anim_speed = get_field('stats_' . $i . '_animation_speed');
            $font_size  = get_field('stats_font_size');
            echo ( $i === 0 ?'
    <div class="d-none d-lg-block col-1 offset-1"></div>' : '' ) . '
    <div class="col-8 offset-2 col-sm-6 offset-sm-3 col-md-4 offset-md-0 col-lg-2 px-lg-0' . ($i > 0 ? ' offset-lg-1 mt-2 mt-md-0' : '') . ($is_preview ? ' content-stats-col' : '') . '">
      <div class="text-primary text-nowrap mb-1 ' . ( !empty($font_size) ? $font_size : 'display4' ) . '"><span>' . $prefix . '</span><span' . ($anim ? ' data-scroll data-scroll-call="countTo" data-count-speed="' . $anim_speed . '"' : '') . '>' . $value . '</span><span>' . $suffix . '</span></div>
      <p class="m-0 px-md-1 px-lg-0">' . $descr . '</p>
    </div>';
        }
    }?>
    
    <div class="col-xs-10 offset-xs-1 col-sm-8 offset-sm-2 col-md-12 offset-md-0 col-lg-10 offset-lg-1 position-absolute zi-n t-0 b-0 l-0">
      <div class="h-100 bg-light"></div>
    </div>
  </div>
</div>
<?php

if($is_preview) {
    echo '
<script type="text/javascript" src="' . get_stylesheet_directory_uri() . '/assets/scripts/editor/script-block-stats.js' . '"></script>';
}?>
