<?php

defined( 'ABSPATH' ) || exit;

$order = wc_get_order( $order_id ); // phpcs:ignore WordPress.WP.GlobalVariablesOverride.OverrideProhibited

if ( ! $order ) {
	return;
}

$order_items           = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
$show_purchase_note    = $order->has_status( apply_filters( 'woocommerce_purchase_note_order_statuses', array( 'completed', 'processing' ) ) );
$show_customer_details = is_user_logged_in() && $order->get_user_id() === get_current_user_id();
$downloads             = $order->get_downloadable_items();
$show_downloads        = $order->has_downloadable_item() && $order->is_download_permitted();

if ( $show_downloads ) {
	wc_get_template(
		'order/order-downloads.php',
		array(
			'downloads'  => $downloads,
			'show_title' => true,
		)
	);
}

do_action( 'woocommerce_order_details_before_order_table', $order );
?>

<div class="content-section-tagline mt-1 mb-0">&nbsp;
  <div class="content-section-tagline-mask border-bottom"></div>
</div>
<div class="content-checkout-stage content-checkout-stage-current content-faq my-1 my-md-2">
  <div class="row position-relative zi-1">
    <div class="col-9 col-md-4 offset-lg-1">
      <h4 class="h2 mb-0"><?php esc_html_e( 'Order details', 'woocommerce' ); ?></h4>
    </div>
    <div class="col-12 col-md-8 col-lg-7">
      <div class="content-faq-description mt-2 mt-md-0">
        <table class="woocommerce-table woocommerce-table--order-details shop_table order_details">
          <thead>
            <tr>
              <th class="woocommerce-table__product-name product-name">
                <?php
                esc_html_e( 'Product', 'woocommerce' );?>
                
              </th>
              <th class="woocommerce-table__product-table product-total">
                <?php
                esc_html_e( 'Total', 'woocommerce' );?>
                
              </th>
            </tr>
          </thead>
          <tbody>
            <?php
            
            do_action( 'woocommerce_order_details_before_order_table_items', $order );
            
            foreach ( $order_items as $item_id => $item ) {
            	$product = $item->get_product();
            
            	wc_get_template(
            		'order/order-details-item.php',
            		array(
            			'order'              => $order,
            			'item_id'            => $item_id,
            			'item'               => $item,
            			'show_purchase_note' => $show_purchase_note,
            			'purchase_note'      => $product ? $product->get_purchase_note() : '',
            			'product'            => $product,
            		)
            	);
            }
            
            do_action( 'woocommerce_order_details_after_order_table_items', $order );?>
            
          </tbody>
          <tfoot>
            <?php
            
            foreach ( $order->get_order_item_totals() as $key => $total ) {
            	?>
            		<tr>
            			<th scope="row"><?php echo esc_html( $total['label'] ); ?></th>
            			<td><?php echo ( 'payment_method' === $key ) ? esc_html( $total['value'] ) : wp_kses_post( $total['value'] ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
            		</tr>
            		<?php
            }
            if ( $order->get_customer_note() ) :?>
            
            <tr>
              <th>
                <?php
                esc_html_e( 'Note:', 'woocommerce' );?>
                
              </th>
              <th>
                <?php
                echo wp_kses_post( nl2br( wptexturize( $order->get_customer_note() ) ) );?>
                
              </th>
            </tr>
            <?php
            endif;?>
            
          </tfoot>
        </table>
      </div>
    </div>
  </div>
</div>
<?php

do_action( 'woocommerce_order_details_after_order_table', $order );

if ( $show_customer_details ) {
	wc_get_template( 'order/order-details-customer.php', array( 'order' => $order ) );
}?>
